
RELEASE_VERSION='0.0.435144901'
BUILD_DATE='Wed Dec 22 16:38:25 UTC 2021'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-0nkb7g 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1913158817'
GIT_COMMIT_SHA='0844d7e7a86e4e8fef3a1000b888198b8cf85080'
GIT_BRANCH='main'
